==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/90/90cbc3852ea61773ec155cea0d50374c.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/js/libraries/froala/languages/sv.js */
class __TwigTemplate_3467e6feb82cfabf90d1919a8a1ef731 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "/*!
 * froala_editor v2.4.2 (https://www.froala.com/wysiwyg-editor)
 * License https://froala.com/wysiwyg-editor/terms/
 * Copyright 2014-2017 Froala Labs
 */

/**
 * Swedish
 */

\$.FE.LANGUAGE['sv'] = {
  translation: {
    // Place holder
    \"Type something\": \"Ange n\\u00e5got\",

    // Basic formatting
    \"Bold\": \"Fetstil\",
    \"Italic\": \"Kursiv stil\",
    \"Underline\": \"Understruken\",
    \"Strikethrough\": \"Genomstruken\",

    // Main buttons
    \"Insert\": \"Infoga\",
    \"Delete\": \"Radera\",
    \"Cancel\": \"Avbryt\",
    \"OK\": \"Ok\",
    \"Back\": \"Tillbaka\",
    \"Remove\": \"Avl\\u00e4gsna\",
    \"More\": \"Vi\\u0161e\",
    \"Update\": \"Uppdatera\",
    \"Style\": \"Stil\",

    // Font
    \"Font Family\": \"Teckensnitt\",
    \"Font Size\": \"Storlek\",

    // Colors
    \"Colors\": \"F\\u00e4rger\",
    \"Background\": \"Bakgrund\",
    \"Text\": \"Text\",

    // Paragraphs
    \"Paragraph Format\": \"Format\",
    \"Normal\": \"Normal\",
    \"Code\": \"Kod\",
    \"Heading 1\": \"Rubrik 1\",
    \"Heading 2\": \"Rubrik 2\",
    \"Heading 3\": \"Rubrik 3\",
    \"Heading 4\": \"Rubrik 4\",

    // Style
    \"Paragraph Style\": \"Styckeformat\",
    \"Inline Style\": \"Infogad stil\",

    // Alignment
    \"Align\": \"Justera\",
    \"Align Left\": \"V\\u00e4nsterst\\u00e4ll\",
    \"Align Center\": \"Centrera\",
    \"Align Right\": \"H\\u00f6gerst\\u00e4ll\",
    \"Align Justify\": \"Justera\",
    \"None\": \"Inget\",

    // Lists
    \"Ordered List\": \"Ordnad lista\",
    \"Unordered List\": \"Oordnad lista\",

    // Indent
    \"Decrease Indent\": \"Minska indrag\",
    \"Increase Indent\": \"\\u00d6ka indrag\",

    // Links
    \"Insert Link\": \"Infoga l\\u00e4nk\",
    \"Open in new tab\": \"\\u00d6ppna i ny flik\",
    \"Open Link\": \"\\u00d6ppna l\\u00e4nk\",
    \"Edit Link\": \"Redigera l\\u00e4nk\",
    \"Unlink\": \"Ta bort l\\u00e4nk\",
    \"Choose Link\": \"V\\u00e4lj l\\u00e4nk\",

    // Images
    \"Insert Image\": \"Infoga bild\",
    \"Upload Image\": \"Ladda upp en bild\",
    \"By URL\": \"Genom URL\",
    \"Browse\": \"Bl\\u00e4ddra\",
    \"Drop image\": \"Sl\\u00e4ppa bild\",
    \"or click\": \"eller klicka\",
    \"Manage Images\": \"Hantera bilder\",
    \"Loading\": \"L\\u00e4ser\",
    \"Deleting\": \"Radera\",
    \"Tags\": \"Taggar\",
    \"Are you sure? Image will be deleted.\": \"\\u00c4r du s\\u00e4ker? Bild kommer att raderas.\",
    \"Replace\": \"Ers\\u00e4tt\",
    \"Uploading\": \"Uppladdning\",
    \"Loading image\": \"Laddar bild\",
    \"Display\": \"Visa\",
    \"Inline\": \"I k\\u00f6\",
    \"Break Text\": \"Break text\",
    \"Alternate Text\": \"Alternativ text\",
    \"Change Size\": \"\\u00c4ndra storlek\",
    \"Width\": \"Bredd\",
    \"Height\": \"H\\u00f6jd\",
    \"Something went wrong. Please try again.\": \"N\\u00e5got gick snett. Var god f\\u00f6rs\\u00f6k igen.\",

    // Video
    \"Insert Video\": \"Infoga video\",
    \"Embedded Code\": \"Inb\\u00e4ddad kod\",

    // Tables
    \"Insert Table\": \"Infoga tabell\",
    \"Table Header\": \"Tabell huvud\",
    \"Remove Table\": \"Ta bort tabellen\",
    \"Table Style\": \"Tabellformat\",
    \"Horizontal Align\": \"Horisontell justering\",
    \"Row\": \"Rad\",
    \"Insert row above\": \"Infoga rad f\\u00f6re\",
    \"Insert row below\": \"Infoga rad efter\",
    \"Delete row\": \"Radera rad\",
    \"Column\": \"Kolumn\",
    \"Insert column before\": \"Infoga kollumn f\\u00f6re\",
    \"Insert column after\": \"Infoga kolumn efter\",
    \"Delete column\": \"Radera kolumn\",
    \"Cell\": \"Cell\",
    \"Merge cells\": \"Sammanfoga celler\",
    \"Horizontal split\": \"Horisontell split\",
    \"Vertical split\": \"Vertikal split\",
    \"Cell Background\": \"Cellbakgrunden\",
    \"Vertical Align\": \"Vertikala justeringen\",
    \"Top\": \"Topp\",
    \"Middle\": \"Mitten\",
    \"Bottom\": \"Botten\",
    \"Align Top\": \"Justera topp\",
    \"Align Middle\": \"Justera mitten\",
    \"Align Bottom\": \"Justera botten\",
    \"Cell Style\": \"Cellformat\",

    // Files
    \"Upload File\": \"Ladda upp fil\",
    \"Drop file\": \"Sl\\u00e4ppa fil\",

    // Emoticons
    \"Emoticons\": \"Uttryckssymboler\",
    \"Grinning face\": \"Grina ansikte\",
    \"Grinning face with smiling eyes\": \"Grina ansikte med leende \\u00f6gon\",
    \"Face with tears of joy\": \"Face med gl\\u00e4djet\\u00e5rar\",
    \"Smiling face with open mouth\": \"Leende ansikte med \\u00f6ppen mun\",
    \"Smiling face with open mouth and smiling eyes\": \"Leende ansikte med \\u00f6ppen mun och leende \\u00f6gon\",
    \"Smiling face with open mouth and cold sweat\": \"Leende ansikte med \\u00f6ppen mun och kallsvett\",
    \"Smiling face with open mouth and tightly-closed eyes\": \"Leende ansikte med \\u00f6ppen mun och t\\u00e4tt slutna \\u00f6gon\",
    \"Smiling face with halo\": \"Leende ansikte med halo\",
    \"Smiling face with horns\": \"Leende ansikte med horn\",
    \"Winking face\": \"Blinka ansikte\",
    \"Smiling face with smiling eyes\": \"Leende ansikte med leende \\u00f6gon\",
    \"Face savoring delicious food\": \"Ansikte smaka uts\\u00f6kt mat\",
    \"Relieved face\": \"L\\u00e4ttad ansikte\",
    \"Smiling face with heart-shaped eyes\": \"Leende ansikte med hj\\u00e4rtformade \\u00f6gon\",
    \"Smiling face with sunglasses\": \"Leende ansikte med solglas\\u00f6gon\",
    \"Smirking face\": \"Flinande ansikte\",
    \"Neutral face\": \"Neutral ansikte\",
    \"Expressionless face\": \"Uttryckslöst ansikte\",
    \"Unamused face\": \"Inte roade ansikte\",
    \"Face with cold sweat\": \"Ansikte med kallsvett\",
    \"Pensive face\": \"Eftert\\u00e4nksamt ansikte\",
    \"Confused face\": \"F\\u00f6rvirrad ansikte\",
    \"Confounded face\": \"F\\u00f6rbryllade ansikte\",
    \"Kissing face\": \"Kyssande ansikte\",
    \"Face throwing a kiss\": \"Ansikte kasta en kyss\",
    \"Kissing face with smiling eyes\": \"Kyssa ansikte med leende \\u00f6gon\",
    \"Kissing face with closed eyes\": \"Kyssa ansikte med slutna \\u00f6gon\",
    \"Face with stuck out tongue\": \"Ansikte med stack ut tungan\",
    \"Face with stuck out tongue and winking eye\": \"Ansikte med stack ut tungan och blinkande \\u00f6ga\",
    \"Face with stuck out tongue and tightly-closed eyes\": \"Ansikte med stack ut tungan och t\\u00e4tt slutna \\u00f6gon\",
    \"Disappointed face\": \"Besviken ansikte\",
    \"Worried face\": \"Orolig ansikte\",
    \"Angry face\": \"Argt ansikte\",
    \"Pouting face\": \"Sk\\u00e4ggtorsk ansikte\",
    \"Crying face\": \"Gr\\u00e5tande ansikte\",
    \"Persevering face\": \"Uth\\u00e5llig ansikte\",
    \"Face with look of triumph\": \"Ansikte med utseendet p\\u00e5 triumf\",
    \"Disappointed but relieved face\": \"Besviken men l\\u00e4ttad ansikte\",
    \"Frowning face with open mouth\": \"Rynkar pannan ansikte med \\u00f6ppen mun\",
    \"Anguished face\": \"\\u00c5ngest ansikte\",
    \"Fearful face\": \"R\\u00e4dda ansikte\",
    \"Weary face\": \"Tr\\u00f6tta ansikte\",
    \"Sleepy face\": \"S\\u00f6mnig ansikte\",
    \"Tired face\": \"Tr\\u00f6tt ansikte\",
    \"Grimacing face\": \"Grimaserande ansikte\",
    \"Loudly crying face\": \"H\\u00f6gt gr\\u00e5tande ansikte\",
    \"Face with open mouth\": \"Ansikte med \\u00f6ppen mun\",
    \"Hushed face\": \"D\\u00e4mpade ansikte\",
    \"Face with open mouth and cold sweat\": \"Ansikte med \\u00f6ppen mun och kallsvett\",
    \"Face screaming in fear\": \"Face skriker i skr\\u00e4ck\",
    \"Astonished face\": \"F\\u00f6rv\\u00e5nad ansikte\",
    \"Flushed face\": \"Ansiktsrodnad\",
    \"Sleeping face\": \"Sovande anskite\",
    \"Dizzy face\": \"Yr ansikte\",
    \"Face without mouth\": \"Ansikte utan mun\",
    \"Face with medical mask\": \"Ansikte med medicinsk maskera\",

    // Line breaker
    \"Break\": \"Break\",

    // Math
    \"Subscript\": \"Neds\\u00e4nkt\",
    \"Superscript\": \"Upph\\u00f6jd text\",

    // Full screen
    \"Fullscreen\": \"Helsk\\u00e4rm\",

    // Horizontal line
    \"Insert Horizontal Line\": \"Infoga horisontell linje\",

    // Clear formatting
    \"Clear Formatting\": \"Ta bort formatering\",

    // Undo, redo
    \"Undo\": \"\\u00c5ngra\",
    \"Redo\": \"G\\u00f6r om\",

    // Select all
    \"Select All\": \"Markera allt\",

    // Code view
    \"Code View\": \"Kodvyn\",

    // Quote
    \"Quote\": \"Citerar\",
    \"Increase\": \"\\u00d6ka\",
    \"Decrease\": \"Minska\",

    // Quick Insert
    \"Quick Insert\": \"Snabb insats\"
  },
  direction: \"ltr\"
};
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/js/libraries/froala/languages/sv.js";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/js/libraries/froala/languages/sv.js", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Assets/js/libraries/froala/languages/sv.js");
    }
}

==> production-demo-20260214_152721.tar.gz: var/www/html/production-demo/var/tmp/twig/90/90cbc3852ea61773ec155cea0d50374c.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/js/libraries/froala/languages/sv.js */
class __TwigTemplate_3467e6feb82cfabf90d1919a8a1ef731 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "/*!
 * froala_editor v2.4.2 (https://www.froala.com/wysiwyg-editor)
 * License https://froala.com/wysiwyg-editor/terms/
 * Copyright 2014-2017 Froala Labs
 */

/**
 * Swedish
 */

\$.FE.LANGUAGE['sv'] = {
  translation: {
    // Place holder
    \"Type something\": \"Ange n\\u00e5got\",

    // Basic formatting
    \"Bold\": \"Fetstil\",
    \"Italic\": \"Kursiv stil\",
    \"Underline\": \"Understruken\",
    \"Strikethrough\": \"Genomstruken\",

    // Main buttons
    \"Insert\": \"Infoga\",
    \"Delete\": \"Radera\",
    \"Cancel\": \"Avbryt\",
    \"OK\": \"Ok\",
    \"Back\": \"Tillbaka\",
    \"Remove\": \"Avl\\u00e4gsna\",
    \"More\": \"Vi\\u0161e\",
    \"Update\": \"Uppdatera\",
    \"Style\": \"Stil\",

    // Font
    \"Font Family\": \"Teckensnitt\",
    \"Font Size\": \"Storlek\",

    // Colors
    \"Colors\": \"F\\u00e4rger\",
    \"Background\": \"Bakgrund\",
    \"Text\": \"Text\",

    // Paragraphs
    \"Paragraph Format\": \"Format\",
    \"Normal\": \"Normal\",
    \"Code\": \"Kod\",
    \"Heading 1\": \"Rubrik 1\",
    \"Heading 2\": \"Rubrik 2\",
    \"Heading 3\": \"Rubrik 3\",
    \"Heading 4\": \"Rubrik 4\",

    // Style
    \"Paragraph Style\": \"Styckeformat\",
    \"Inline Style\": \"Infogad stil\",

    // Alignment
    \"Align\": \"Justera\",
    \"Align Left\": \"V\\u00e4nsterst\\u00e4ll\",
    \"Align Center\": \"Centrera\",
    \"Align Right\": \"H\\u00f6gerst\\u00e4ll\",
    \"Align Justify\": \"Justera\",
    \"None\": \"Inget\",

    // Lists
    \"Ordered List\": \"Ordnad lista\",
    \"Unordered List\": \"Oordnad lista\",

    // Indent
    \"Decrease Indent\": \"Minska indrag\",
    \"Increase Indent\": \"\\u00d6ka indrag\",

    // Links
    \"Insert Link\": \"Infoga l\\u00e4nk\",
    \"Open in new tab\": \"\\u00d6ppna i ny flik\",
    \"Open Link\": \"\\u00d6ppna l\\u00e4nk\",
    \"Edit Link\": \"Redigera l\\u00e4nk\",
    \"Unlink\": \"Ta bort l\\u00e4nk\",
    \"Choose Link\": \"V\\u00e4lj l\\u00e4nk\",

    // Images
    \"Insert Image\": \"Infoga bild\",
    \"Upload Image\": \"Ladda upp en bild\",
    \"By URL\": \"Genom URL\",
    \"Browse\": \"Bl\\u00e4ddra\",
    \"Drop image\": \"Sl\\u00e4ppa bild\",
    \"or click\": \"eller klicka\",
    \"Manage Images\": \"Hantera bilder\",
    \"Loading\": \"L\\u00e4ser\",
    \"Deleting\": \"Radera\",
    \"Tags\": \"Taggar\",
    \"Are you sure? Image will be deleted.\": \"\\u00c4r du s\\u00e4ker? Bild kommer att raderas.\",
    \"Replace\": \"Ers\\u00e4tt\",
    \"Uploading\": \"Uppladdning\",
    \"Loading image\": \"Laddar bild\",
    \"Display\": \"Visa\",
    \"Inline\": \"I k\\u00f6\",
    \"Break Text\": \"Break text\",
    \"Alternate Text\": \"Alternativ text\",
    \"Change Size\": \"\\u00c4ndra storlek\",
    \"Width\": \"Bredd\",
    \"Height\": \"H\\u00f6jd\",
    \"Something went wrong. Please try again.\": \"N\\u00e5got gick snett. Var god f\\u00f6rs\\u00f6k igen.\",

    // Video
    \"Insert Video\": \"Infoga video\",
    \"Embedded Code\": \"Inb\\u00e4ddad kod\",

    // Tables
    \"Insert Table\": \"Infoga tabell\",
    \"Table Header\": \"Tabell huvud\",
    \"Remove Table\": \"Ta bort tabellen\",
    \"Table Style\": \"Tabellformat\",
    \"Horizontal Align\": \"Horisontell justering\",
    \"Row\": \"Rad\",
    \"Insert row above\": \"Infoga rad f\\u00f6re\",
    \"Insert row below\": \"Infoga rad efter\",
    \"Delete row\": \"Radera rad\",
    \"Column\": \"Kolumn\",
    \"Insert column before\": \"Infoga kollumn f\\u00f6re\",
    \"Insert column after\": \"Infoga kolumn efter\",
    \"Delete column\": \"Radera kolumn\",
    \"Cell\": \"Cell\",
    \"Merge cells\": \"Sammanfoga celler\",
    \"Horizontal split\": \"Horisontell split\",
    \"Vertical split\": \"Vertikal split\",
    \"Cell Background\": \"Cellbakgrunden\",
    \"Vertical Align\": \"Vertikala justeringen\",
    \"Top\": \"Topp\",
    \"Middle\": \"Mitten\",
    \"Bottom\": \"Botten\",
    \"Align Top\": \"Justera topp\",
    \"Align Middle\": \"Justera mitten\",
    \"Align Bottom\": \"Justera botten\",
    \"Cell Style\": \"Cellformat\",

    // Files
    \"Upload File\": \"Ladda upp fil\",
    \"Drop file\": \"Sl\\u00e4ppa fil\",

    // Emoticons
    \"Emoticons\": \"Uttryckssymboler\",
    \"Grinning face\": \"Grina ansikte\",
    \"Grinning face with smiling eyes\": \"Grina ansikte med leende \\u00f6gon\",
    \"Face with tears of joy\": \"Face med gl\\u00e4djet\\u00e5rar\",
    \"Smiling face with open mouth\": \"Leende ansikte med \\u00f6ppen mun\",
    \"Smiling face with open mouth and smiling eyes\": \"Leende ansikte med \\u00f6ppen mun och leende \\u00f6gon\",
    \"Smiling face with open mouth and cold sweat\": \"Leende ansikte med \\u00f6ppen mun och kallsvett\",
    \"Smiling face with open mouth and tightly-closed eyes\": \"Leende ansikte med \\u00f6ppen mun och t\\u00e4tt slutna \\u00f6gon\",
    \"Smiling face with halo\": \"Leende ansikte med halo\",
    \"Smiling face with horns\": \"Leende ansikte med horn\",
    \"Winking face\": \"Blinka ansikte\",
    \"Smiling face with smiling eyes\": \"Leende ansikte med leende \\u00f6gon\",
    \"Face savoring delicious food\": \"Ansikte smaka uts\\u00f6kt mat\",
    \"Relieved face\": \"L\\u00e4ttad ansikte\",
    \"Smiling face with heart-shaped eyes\": \"Leende ansikte med hj\\u00e4rtformade \\u00f6gon\",
    \"Smiling face with sunglasses\": \"Leende ansikte med solglas\\u00f6gon\",
    \"Smirking face\": \"Flinande ansikte\",
    \"Neutral face\": \"Neutral ansikte\",
    \"Expressionless face\": \"Uttryckslöst ansikte\",
    \"Unamused face\": \"Inte roade ansikte\",
    \"Face with cold sweat\": \"Ansikte med kallsvett\",
    \"Pensive face\": \"Eftert\\u00e4nksamt ansikte\",
    \"Confused face\": \"F\\u00f6rvirrad ansikte\",
    \"Confounded face\": \"F\\u00f6rbryllade ansikte\",
    \"Kissing face\": \"Kyssande ansikte\",
    \"Face throwing a kiss\": \"Ansikte kasta en kyss\",
    \"Kissing face with smiling eyes\": \"Kyssa ansikte med leende \\u00f6gon\",
    \"Kissing face with closed eyes\": \"Kyssa ansikte med slutna \\u00f6gon\",
    \"Face with stuck out tongue\": \"Ansikte med stack ut tungan\",
    \"Face with stuck out tongue and winking eye\": \"Ansikte med stack ut tungan och blinkande \\u00f6ga\",
    \"Face with stuck out tongue and tightly-closed eyes\": \"Ansikte med stack ut tungan och t\\u00e4tt slutna \\u00f6gon\",
    \"Disappointed face\": \"Besviken ansikte\",
    \"Worried face\": \"Orolig ansikte\",
    \"Angry face\": \"Argt ansikte\",
    \"Pouting face\": \"Sk\\u00e4ggtorsk ansikte\",
    \"Crying face\": \"Gr\\u00e5tande ansikte\",
    \"Persevering face\": \"Uth\\u00e5llig ansikte\",
    \"Face with look of triumph\": \"Ansikte med utseendet p\\u00e5 triumf\",
    \"Disappointed but relieved face\": \"Besviken men l\\u00e4ttad ansikte\",
    \"Frowning face with open mouth\": \"Rynkar pannan ansikte med \\u00f6ppen mun\",
    \"Anguished face\": \"\\u00c5ngest ansikte\",
    \"Fearful face\": \"R\\u00e4dda ansikte\",
    \"Weary face\": \"Tr\\u00f6tta ansikte\",
    \"Sleepy face\": \"S\\u00f6mnig ansikte\",
    \"Tired face\": \"Tr\\u00f6tt ansikte\",
    \"Grimacing face\": \"Grimaserande ansikte\",
    \"Loudly crying face\": \"H\\u00f6gt gr\\u00e5tande ansikte\",
    \"Face with open mouth\": \"Ansikte med \\u00f6ppen mun\",
    \"Hushed face\": \"D\\u00e4mpade ansikte\",
    \"Face with open mouth and cold sweat\": \"Ansikte med \\u00f6ppen mun och kallsvett\",
    \"Face screaming in fear\": \"Face skriker i skr\\u00e4ck\",
    \"Astonished face\": \"F\\u00f6rv\\u00e5nad ansikte\",
    \"Flushed face\": \"Ansiktsrodnad\",
    \"Sleeping face\": \"Sovande anskite\",
    \"Dizzy face\": \"Yr ansikte\",
    \"Face without mouth\": \"Ansikte utan mun\",
    \"Face with medical mask\": \"Ansikte med medicinsk maskera\",

    // Line breaker
    \"Break\": \"Break\",

    // Math
    \"Subscript\": \"Neds\\u00e4nkt\",
    \"Superscript\": \"Upph\\u00f6jd text\",

    // Full screen
    \"Fullscreen\": \"Helsk\\u00e4rm\",

    // Horizontal line
    \"Insert Horizontal Line\": \"Infoga horisontell linje\",

    // Clear formatting
    \"Clear Formatting\": \"Ta bort formatering\",

    // Undo, redo
    \"Undo\": \"\\u00c5ngra\",
    \"Redo\": \"G\\u00f6r om\",

    // Select all
    \"Select All\": \"Markera allt\",

    // Code view
    \"Code View\": \"Kodvyn\",

    // Quote
    \"Quote\": \"Citerar\",
    \"Increase\": \"\\u00d6ka\",
    \"Decrease\": \"Minska\",

    // Quick Insert
    \"Quick Insert\": \"Snabb insats\"
  },
  direction: \"ltr\"
};
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/js/libraries/froala/languages/sv.js";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/js/libraries/froala/languages/sv.js", "/var/www/html/production-demo/app/bundles/CoreBundle/Assets/js/libraries/froala/languages/sv.js");
    }
}
